==> kyamo_0.13.99+0.2a.orig.tar.gz: kyamo-0.2a/src/aboutdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert                                  *
 *   roweigert@t-online.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "aboutdialog.h"

aboutdialog::aboutdialog(QWidget *pointer)
{

  aboutbox=new QGroupBox(2,Qt::Vertical,pointer);
  new QLabel (i18n("<center><b>KDE Yet Another Music Organizer</b><br><br>Version 0.2a<br><br>Roland Weigert<br>roweigert@users.sourceforge.net</center>"),aboutbox);
}
aboutdialog::~aboutdialog()
{
  delete aboutbox;
}

==> kyamo_0.40+0.4a.orig.tar.gz: kyamo-0.40a4-2/src/aboutdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert                                  *
 *   roweigert@t-online.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "aboutdialog.h"

aboutdialog::aboutdialog(QWidget *pointer)
{

  aboutbox=new QGroupBox(2,Qt::Vertical,pointer);
  QString aboutstring=QString(i18n("<center><b>KDE Yet Another Music Organizer</b><br><br>Version %1<br><br>Roland Weigert<br>roweigert@users.sourceforge.net</center>")).arg(KYAMOVERSION);
  aboutlabel=new QLabel (i18n(aboutstring),aboutbox);
}
aboutdialog::~aboutdialog()
{
  cerr<<"aboutdialog destructor"<<endl;
  delete aboutlabel;
  delete aboutbox;
}
